OC.L10N.register(
    "mail",
    {
    "Mail" : "Posta",
    "Error while loading the accounts." : "Gabim gjatë ngarkimit të llogarive.",
    "Can not load this folder." : "Nuk mund të ngarkohet kjo dosje.",
    "Searching for {query}" : "Duke kërkuar për {query}",
    "Error while deleting message." : "Gabim gjatë fshirjes së mesazhit.",
    "Forwarded message" : "Mesazhi u përcoll",
    "Choose a folder to store the attachment in" : "Zgjidhni një dosje ku të depozitohet bashkëngjitja",
    "Attachments saved to Files." : "Bashkëngjitjet u ruajtën te Skedarët.",
    "Attachment saved to Files." : "Bashkëngjitjet u ruajtën tek dosja.",
    "Error while saving attachments to Files." : "Gabim teksa ruheshin bashkëngjitje tek dosja.",
    "Error while saving attachment to Files." : "Gabim teksa ruheshin bashkëngjitje tek dosjet",
    "Message flag could not be set." : "Mesazhit s’iu vu dot shenjë.",
    "Could not move message." : "Mesazhi nuk mund të lëvizej.",
    "Invalid account" : "Llogari e pavlefshme",
    "Invalid folder" : "Dosje e pavlefshme",
    "Error while creating the account: " : "Problem gjatë krijimit të llogarisë:",
    "Unknown error" : "Gabim i panjohur",
    "All inboxes" : "Krejt kutitë e postës",
    "you" : "ju",
    "Send message to {email}" : "Dërgoni mesazh te {email}",
    "Could not load {tag}{name}{endtag}" : "Nuk mund të ngarkohej {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Pati një problem me ngarkimin e {tag}{name}{endtag}",
    "{from}\n{subject}" : "{nga}\n{subjekt}",
    "Save" : "Ruaj",
    "Show all folders" : "Shfaqi krejt dosjet",
    "Collapse folders" : "Tkurri dosjet",
    "Error while deleting account." : "Gabim gjatë fshirjes së llogarisë.",
    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
    "Reply" : "Përgjigju",
    "Send" : "Dërgo",
    "Sending …" : "Po dërgohet …",
    "Message sent!" : "Mesazhi u dërgua!",
    "Server error" : "Gabim shërbyesi",
    "An unknown error occurred" : "Ndodhi një gabim i panjohur",
    "Opening HTML drafts is not supported yet." : "Hapja e skicave HTML nuk mbulohet ende.",
    "No writable calendars found" : "S’u gjetën kalendarë të shkruajtshëm",
    "Error while importing the calendar event" : "Gabim gjatë importimit të veprimtarisë së kalendarit",
    "Error while downloading calendar event" : "Gabim gjatë shkarkimit të veprimtarisë së kalendarit",
    "& others" : "& të tjerë",
    "Error while loading messages." : "Gabim gjatë ngarkimit të mesazheve.",
    "Setting up your account" : "Duke krijuar llogarinë tuaj",
    "Inbox" : "Të marrë",
    "Sent" : "Të dërguar",
    "Drafts" : "Skica",
    "Archive" : "Arkivë",
    "Trash" : "Hedhurina",
    "Junk" : "Të pavlera",
    "All" : "Të gjithë",
    "Favorites" : "Të parapëlqyer",
    "Auto detect failed. Please use manual mode." : "Vetëzbulimi dështoi. Ju lutemi, përdorni metodën dorazi.",
    "Creating account failed: " : "Krijimi i llogarisë dështoi: ",
    "Delete permanently" : "Fshije përgjithmonë",
    "Error loading message" : "Gabim në ngarkimin e kartelës",
    "Settings" : "Konfigurimet",
    "Forwarding to %s" : "Ridrejto te %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikoni këtu nëse nuk ridrejtoheni automatikisht brenda disa sekondave",
    "Redirect" : "Ridrejtoje",
    "The link leads to %s" : "Lidhja shpie te %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Nëse s’doni ta vizitoni atë faqe, mund të ktheheni te <a href=\"%s\">Posta</a>.",
    "Continue to %s" : "Vazhdo te %s",
    "Delete account" : "Fshij llogarinë",
    "Try again" : "Provo përsëri",
    "New message" : "Mesazh i ri",
    "Account Settings" : "Konfigurimet e llogarisë",
    "Aliases" : "Emërtimet",
    "Mail address" : "Adresa e postës elektronike",
    "Display Name" : "Trego Emrin",
    "Account" : "Llogari",
    "Keyboard shortcuts" : "Shkurtoret e tastierës",
    "Speed up your Mail experience with these quick shortcuts." : "Përmirësoni përvojën tuaj në Mail me këto shkurtore të shpejta.",
    "Newer message" : "Mesazhe më të reja",
    "Older message" : "Mesazhe më të vjetra",
    "Toggle star" : "Toggle star",
    "Toggle unread" : "Toggle i pa lexuar",
    "Delete" : "Fshij",
    "Search" : "Kërko",
    "Refresh" : "Rifresko",
    "Connect your mail account" : "Lidhni llogarinë tuaj të postës elektronike",
    "Name" : "Emri",
    "Mail Address" : "Adresa e postës elektronike",
    "Password" : "Fjalëkalimi",
    "Manual configuration" : "Konfigurim manual",
    "IMAP Host" : "Strehë IMAP",
    "IMAP security" : "Siguria IMAP",
    "None" : "Asnjë",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porta IMAP",
    "IMAP User" : "Përdorues IMAP",
    "IMAP Password" : "Fjalëkalimi i IMAP",
    "SMTP Host" : "Streha e SMTP",
    "SMTP security" : "Siguria e SMTP",
    "SMTP Port" : "Porta SMTP",
    "SMTP User" : "Përdoruesi i SMTP",
    "SMTP Password" : "Fjalëkalimi SMTP",
    "Connect" : "Lidhu",
    "from" : "nga",
    "to" : "te",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Temë",
    "Save all to Files" : "Ruaji të gjitha te Dosjet",
    "Add mail account" : "Shto llogarinë e postës elektronike",
    "No search results for" : "Asnjë rezultat kërkimi për",
    "The images have been blocked to protect your privacy." : "Imazhet janë bllokuar për të mbrojtur privatësinë tuaj.",
    "Show images from this sender" : "Trego imazhet nga ky dërgues",
    "Forward" : "Ridrejto",
    "Upload attachment" : "Ngarko bashkëngjitje",
    "Import into calendar" : "Importo në kalendar",
    "Download attachment" : "Shkarko bashkëlidhjen",
    "Save to Files" : "Ruaje te Skedarët"
},
"nplurals=2; plural=(n != 1);");
